@@ -83,7 +83,7 @@ def run(team_name, job, **kwargs):
   if os.path.exists('./job.dill'):
     os.remove('./job.dill')
 
-  dill.dump(job, open('./job.dill', mode='wb'), recurse=True)
+  dill.dump(job, open('./job.dill', mode='wb'), byref=False, recurse=True)
 
   if os.path.exists('./reqs.txt'):
     os.remove('./reqs.txt')
@@ -152,7 +152,7 @@ def deploy(model, **kwargs):
   if os.path.exists('./model.dill'):
     os.remove('./model.dill')
 
-  dill.dump(prediction_fn, open('./model.dill', mode='wb'), recurse=True)
+  dill.dump(prediction_fn, open('./model.dill', mode='wb'), byref=False, recurse=True))
 
   if os.path.exists('./reqs.txt'):
     os.remove('./reqs.txt')
